'use strict'

let core = require('babel-core')
let debug = require('debug')('mako-babel')
let defaults = require('defaults')
let utils = require('mako-utils')

let compile = core.transform
let shouldIgnore = core.util.shouldIgnore

module.exports = function (options) {
  debug('initialize %j', options)

  let config = defaults(options, {
    extensions: 'js',
    ignore: [ /node_modules/i ],
    plugins: [],
    presets: [],
    only: null,
    sourceMaps: false
  })

  return function (mako) {
    mako.postread(config.extensions, function babel (file, build) {
      if (shouldIgnore(file.path, config.ignore, config.only)) {
        return debug('ignoring %s', utils.relative(file.path))
      }

      let timer = build.time('babel')
      debug('compiling %s', utils.relative(file.path))
      let results = compile(file.contents.toString(), {
        filename: file.path,
        sourceMaps: config.sourceMaps ? 'inline' : false,
        plugins: config.plugins,
        presets: config.presets
      })

      file.contents = new Buffer(results.code)
      file.type = 'js'
      timer()
    })
  }
}
